@@ -7,7 +7,7 @@ A mkdocs plugin that support conversion from
 """
 
 
-class ObsidianSupportPlugin(BasePlugin):
+class LinkPreviewPlugin(BasePlugin):
 
     def on_page_markdown(self, markdown, page, config, files):
         ## apply conversions
